@@ -71,11 +71,9 @@ import javax.servlet.ServletOutputStream;
 import javax.servlet.http.HttpServlet;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-import org.apache.commons.logging.Log;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.AllocatingStringWriter;
-import com.openexchange.log.LogFactory;
 import com.openexchange.mobile.configuration.generator.configuration.ConfigurationException;
 import com.openexchange.mobile.configuration.generator.configuration.MobileConfigProperties;
 import com.openexchange.mobile.configuration.generator.configuration.Property;
@@ -133,7 +131,7 @@ public class MobileConfigServlet extends HttpServlet {
 
     }
 
-    private static final transient Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MobileConfigServlet.class));
+    private static final transient org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MobileConfigServlet.class);
 
     /**
      *
@@ -225,7 +223,7 @@ public class MobileConfigServlet extends HttpServlet {
                 }
             }
         } catch (final ConfigurationException e) {
-            LOG.error("A configuration exception occurred, which should not happen: " + e.getMessage(), e);
+            LOG.error("A configuration exception occurred, which should not happen", e);
             printError(req, resp, ErrorMessage.MSG_INTERNAL_ERROR);
             return;
         }
@@ -255,7 +253,7 @@ public class MobileConfigServlet extends HttpServlet {
                     return;
                 } else {
                     printError(req, resp, ErrorMessage.MSG_NO_SUPPORTED_DEVICE_FOUND);
-                    LOG.info("Unsupported device header: \"" + header + "\"");
+                    LOG.info("Unsupported device header: \"{}\"", header);
                     return;
                 }
             }
@@ -263,11 +261,11 @@ public class MobileConfigServlet extends HttpServlet {
             try {
                 generateConfig(req, resp, login, device);
             } catch (final OXException e) {
-                LOG.error("A template exception occurred, which should not happen: " + e.getMessage(), e);
+                LOG.error("A template exception occurred, which should not happen", e);
                 printError(req, resp, ErrorMessage.MSG_INTERNAL_ERROR);
                 return;
             } catch (final IOException e) {
-                LOG.error("A template exception occurred, which should not happen: " + e.getMessage(), e);
+                LOG.error("A template exception occurred, which should not happen", e);
                 printError(req, resp, ErrorMessage.MSG_INTERNAL_ERROR);
                 return;
             }
@@ -317,7 +315,7 @@ public class MobileConfigServlet extends HttpServlet {
         try {
             writer = getWriterFromOutputStream(resp.getOutputStream());
         } catch (final IOException e) {
-            LOG.error("Unable to get output stream to write error message: " + e.getMessage(), e);
+            LOG.error("Unable to get output stream to write error message", e);
             return;
         }
         if (ErrorMessage.MSG_PARAMETER_LOGIN_IS_MISSING.equals(msg)) {
@@ -411,10 +409,10 @@ public class MobileConfigServlet extends HttpServlet {
         try {
             return new PrintWriter(new OutputStreamWriter(new BufferedOutputStream(outputStream), Charset.forName("UTF-8")));
         } catch (final IllegalCharsetNameException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         } catch (final UnsupportedCharsetException e) {
-            LOG.error(e.getMessage(), e);
+            LOG.error("", e);
             throw e;
         }
     }
